@@ -1,6 +1,6 @@
 ; Scheme 9 from Empty Space
 ; Test Suite
-; By Nils M Holm, 2007-2010
+; By Nils M Holm, 2007-2012
 
 ;  This is a comment
 
@@ -95,6 +95,16 @@
 (test '(a (b) c) '(a (b) c))
 (test '(((((x))))) '(((((x))))))
 (test '((caar . cdar) . (cadr . cddr)) '((caar . cdar) . (cadr . cddr)))
+(test '[] '())
+(test '[a b c] '(a b c))
+(test '(a [b] c) '(a (b) c))
+(test '[a (b) c] '(a (b) c))
+(test '[a [b] c] '(a (b) c))
+(test '(((((x))))) '(((((x))))))
+(test '([([(x)])]) '(((((x))))))
+(test '[([([x])])] '(((((x))))))
+(test '[[[[[x]]]]] '(((((x))))))
+(test '([caar . cdar] . [cadr . cddr]) '((caar . cdar) . (cadr . cddr)))
 
 ; vectors
 
@@ -821,11 +831,16 @@
 (test (list? '(1 2 3)) #t)
 (test (list? '(1 . 2)) #f)
 (test (list? '(1 2 . 3)) #f)
-(let ((cyclic (list 1 2 3)))
-  (set-cdr! (cddr cyclic) cyclic)
-  (if (list? cyclic)
-      (fail '(list? 'cyclic) #t)
-      (test (list? 'cyclic) #f)))
+(let ((cyclic2 (list 1 2))
+      (cyclic3 (list 1 2 3)))
+  (set-cdr! (cdr cyclic2) cyclic2)
+  (set-cdr! (cddr cyclic3) cyclic3)
+  (if (list? cyclic2)
+      (fail '(list? 'cyclic2) #t)
+      (test (list? 'cyclic2) #f))
+  (if (list? cyclic3)
+      (fail '(list? 'cyclic3) #t)
+      (test (list? 'cyclic3) #f)))
 
 (test (member 'c '(a b)) #f)
 (test (member 'b '(a b)) '(b))
@@ -1155,12 +1170,69 @@
 (test (equal? #\c #\c) #t)
 (test (equal? 1 1) #t)
 (test (equal? '(pair) '(pair)) #t)
+(test (equal? '(pair (1)) '(pair (2))) #f)
 (test (equal? (lambda () #f) (lambda () #f)) #f)
 (test (equal? "string" "string") #t)
 (test (equal? 'symbol 'symbol) #t)
 (test (equal? '#(vector) #(vector)) #t)
+(test (equal? '#(vector (list) vector) #(vector (list) vector)) #t)
+(test (equal? '#(vector #(vector) vector) #(vector #(vector) vector)) #t)
+(test (equal? '#(vector #(vec1) vector) #(vector #(vec2) vector)) #f)
 (test (equal? tree tree) #t)
 
+(test (equal? #f #\c) #f)
+(test (equal? #f 1) #f)
+(test (equal? #f '(pair)) #f)
+(test (equal? #f (lambda () #f)) #f)
+(test (equal? #f "string") #f)
+(test (equal? #f 'symbol) #f)
+(test (equal? #f '#(vector)) #f)
+(test (equal? #f (current-input-port)) #f)
+(test (equal? #f (current-output-port)) #f)
+(test (equal? #\c 1) #f)
+(test (equal? #\c '(pair)) #f)
+(test (equal? #\c (lambda () #f)) #f)
+(test (equal? #\c "string") #f)
+(test (equal? #\c 'symbol) #f)
+(test (equal? #\c '#(vector)) #f)
+(test (equal? #\c (current-input-port)) #f)
+(test (equal? #\c (current-output-port)) #f)
+(test (equal? 1 '(pair)) #f)
+(test (equal? 1 (lambda () #f)) #f)
+(test (equal? 1 "string") #f)
+(test (equal? 1 'symbol) #f)
+(test (equal? 1 '#(vector)) #f)
+(test (equal? 1 (current-input-port)) #f)
+(test (equal? 1 (current-output-port)) #f)
+(test (equal? '(pair) (lambda () #f)) #f)
+(test (equal? '(pair) "string") #f)
+(test (equal? '(pair) 'symbol) #f)
+(test (equal? '(pair) '#(vector)) #f)
+(test (equal? '(pair) (current-input-port)) #f)
+(test (equal? '(pair) (current-output-port)) #f)
+(test (equal? (lambda () #f) "string") #f)
+(test (equal? (lambda () #f) 'symbol) #f)
+(test (equal? (lambda () #f) '#(vector)) #f)
+(test (equal? (lambda () #f) (current-input-port)) #f)
+(test (equal? (lambda () #f) (current-output-port)) #f)
+(test (equal? "string" 'symbol) #f)
+(test (equal? "string" '#(vector)) #f)
+(test (equal? "string" (current-input-port)) #f)
+(test (equal? "string" (current-output-port)) #f)
+(test (equal? 'symbol '#(vector)) #f)
+(test (equal? 'symbol (current-input-port)) #f)
+(test (equal? 'symbol (current-output-port)) #f)
+(test (equal? '#(vector) (current-input-port)) #f)
+(test (equal? '#(vector) (current-output-port)) #f)
+(test (equal? (current-input-port) (current-output-port)) #f)
+
+(test (let ((x (list 1))) (equal? x x)) #t)
+
+(test (equal? '(a (b c) (d (e . f) g)) '(a (b c) (d (e . f) g))) #t)
+(test (equal? '(a (b c) (d (e . x) g)) '(a (b c) (d (e . f) g))) #f)
+(test (equal? '#(a (b c) (d (e . f) g)) '#(a (b c) (d (e . f) g))) #t)
+(test (equal? '#(a (b c) (d (e . x) g)) '#(a (b c) (d (e . f) g))) #f)
+
 ; --- chars ---
 
 (test (char-alphabetic? #\a) #t)
@@ -1464,6 +1536,8 @@
 (test (string-append "" "") "")
 (test (string-append "abc" "") "abc")
 (test (string-append "" "def") "def")
+(test (string-append) "")
+(test (string-append "abc") "abc")
 (test (string-append "abc" "def") "abcdef")
 (test (string-append "abc" "def" "xyz") "abcdefxyz")
 
